pub struct ResolvedRange {
pub start: u64,
pub length: u64,
pub regions: Vec<MemoryRegionInfo>,
}Expand description
A resolved, non-overlapping address range in the memory map.
Each range contains an ordered list of memory regions that overlap at this interval. The first region is the active (highest priority) one.
This is a snapshot value — it is not updated by later mutations to the memory map.
Fields
start: u64length: u64regions: Vec<MemoryRegionInfo>Implementations
Sourceimpl ResolvedRange
impl ResolvedRange
pub fn end(&self) -> u64
Sourcepub fn active_region(&self) -> Option<&MemoryRegionInfo>
pub fn active_region(&self) -> Option<&MemoryRegionInfo>
The highest-priority region at this range.
Sourcepub fn flags(&self) -> SegmentFlags
pub fn flags(&self) -> SegmentFlags
Flags of the active (highest-priority) region.